=====
Usage
=====

After following :ref:`installation:Installation` instructions,
to use CogZen in a project:

    >>> import cogzen

.. note::
   See :ref:`package docs <cogzen:cogzen package>` section for documentation.
